Instrument Drivers
^^^^^^^^^^^^^^^^^^

Base Instrument
---------------

.. autoclass:: zhinst.toolkit.control.drivers.base.BaseInstrument
    :members:

    .. automethod:: _get

    .. automethod:: _set


HDAWG
-----    

.. autoclass:: zhinst.toolkit.HDAWG
    :show-inheritance:
    :members:

AWGCore for the HDAWG
+++++++++++++++++++++

.. autoclass:: zhinst.toolkit.control.drivers.hdawg.AWG
    :show-inheritance:
    :members:


UHFQA
-----

.. autoclass:: zhinst.toolkit.UHFQA
    :show-inheritance:
    :members:

AWGCore for the UHFQA
+++++++++++++++++++++

.. autoclass:: zhinst.toolkit.control.drivers.uhfqa.AWG
    :show-inheritance:
    :members:

Readout Channel
+++++++++++++++

.. autoclass:: zhinst.toolkit.control.drivers.uhfqa.ReadoutChannel
    :show-inheritance:
    :members:



UHFLI
-----

.. autoclass:: zhinst.toolkit.UHFLI
    :show-inheritance:
    :members:


MFLI
-----

.. autoclass:: zhinst.toolkit.MFLI
    :show-inheritance:
    :members:
